summaryrefslogtreecommitdiffstats
path: root/module/plugins/internal/SimpleHoster.py
diff options
context:
space:
mode:
Diffstat (limited to 'module/plugins/internal/SimpleHoster.py')
-rw-r--r--module/plugins/internal/SimpleHoster.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/module/plugins/internal/SimpleHoster.py b/module/plugins/internal/SimpleHoster.py
index 6f1c7409d..8b1527b3e 100644
--- a/module/plugins/internal/SimpleHoster.py
+++ b/module/plugins/internal/SimpleHoster.py
@@ -30,7 +30,7 @@ def _error(self, reason, type):
type = "unknown"
msg = _("%s error") % type.strip().capitalize() if type else _("Error")
- msg += ": %s" % reason.strip() if reason else ""
+ msg += (": %s" % reason.strip()) if reason else ""
msg += _(" | Plugin may be out of date")
raise Fail(msg)
@@ -238,7 +238,7 @@ def secondsToMidnight(gmt=0):
if hasattr(td, 'total_seconds'):
res = td.total_seconds()
- else: #: work-around for python 2.5 and 2.6 missing datetime.timedelta.total_seconds
+ else: #@NOTE: work-around for python 2.5 and 2.6 missing datetime.timedelta.total_seconds
res = (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / 10**6
return int(res)
@@ -247,7 +247,7 @@ def secondsToMidnight(gmt=0):
class SimpleHoster(Hoster):
__name__ = "SimpleHoster"
__type__ = "hoster"
- __version__ = "1.33"
+ __version__ = "1.35"
__pattern__ = r'^unmatchable$'
__config__ = [("use_premium", "bool", "Use premium account if available", True)]
@@ -315,7 +315,7 @@ class SimpleHoster(Hoster):
@classmethod
- def parseInfos(cls, urls): #@TODO: Built-in in 0.4.10 core, then remove from plugins
+ def parseInfos(cls, urls): #@TODO: Built-in in 0.4.10 core (remove from plugins)
for url in urls:
url = replace_patterns(url, cls.URL_REPLACEMENTS)
yield cls.getInfo(url)
@@ -498,7 +498,7 @@ class SimpleHoster(Hoster):
raise Fail(e)
#: Work-around to `filename*=UTF-8` bug; remove in 0.4.10
def download(self, url, get={}, post={}, ref=True, cookies=True, disposition=False):
try:
if disposition:
@@ -498,7 +498,7 @@ class SimpleHoster(Hoster):
raise Fail(e)
- #: Work-around to `filename*=UTF-8` bug; remove in 0.4.10
+ #@NOTE: Work-around to `filename*=UTF-8` bug; remove in 0.4.10
def download(self, url, get={}, post={}, ref=True, cookies=True, disposition=False):
try: